@@ -5,7 +5,6 @@
 #include <RcppArmadillo.h>
 #include <iostream>
 #include <vector>
-#include <cassert>
 
 using namespace Rcpp;
 using namespace arma;
@@ -17,10 +16,10 @@ using namespace arma;
 //' @param Lmax largest degree of spherical harmonics. 
 //' Current only Lmax=2 supported
 // [[Rcpp::export]]
-arma::cube sph_grad_xyz( NumericMatrix xyz, int Lmax ){
+arma::cube sph_grad_xyz( arma::mat xyz, int Lmax ){
     
     int nbasis = (Lmax+1)*(Lmax+1) - 4;
-    int n = xyz.nrow();
+    int n = xyz.n_rows;
     cube grad_basis = cube( n, nbasis, 3, fill::zeros );
     
     if(Lmax > 1){
