@@ -5,8 +5,6 @@
 #include <RcppArmadillo.h>
 #include <iostream>
 #include <vector>
-#include "basis.h"
-#include "covmatrix_funs_01.h"
 
 using namespace Rcpp;
 using namespace arma;
